pub struct BlockEntityType {
pub key: Identifier,
pub valid_blocks: &'static [BlockRef],
}Expand description
Represents a block entity type in Minecraft. Block entities are used for blocks that need to store additional data beyond their block state, such as chests, furnaces, signs, etc.
Fields
key: Identifiervalid_blocks: &'static [BlockRef]Blocks for which vanilla accepts this block entity type.
Implementations