pub struct BlockEntityTypeRegistry {
block_entity_types_by_id: Vec<BlockEntityTypeRef>,
block_entity_types_by_key: FxHashMap<Identifier, usize>,
blocks_with_block_entities: Vec<bool>,
allows_registering: bool,
}Fields
block_entity_types_by_id: Vec<BlockEntityTypeRef>block_entity_types_by_key: FxHashMap<Identifier, usize>blocks_with_block_entities: Vec<bool>allows_registering: boolImplementations
Sourceimpl BlockEntityTypeRegistry
impl BlockEntityTypeRegistry
pub fn new() -> Self
pub fn register(&mut self, block_entity_type: BlockEntityTypeRef) -> usize
pub fn iter(&self) -> impl Iterator<Item = (usize, BlockEntityTypeRef)> + '_
Sourcepub fn has_block_entity(&self, block: BlockRef) -> bool
pub fn has_block_entity(&self, block: BlockRef) -> bool
Returns whether at least one block entity type accepts block.
Vanilla does not require those accepted-block sets to be globally disjoint, so creation remains the owning block behavior’s responsibility.